@@ -11,12 +11,12 @@
  *  Synerty Pty Ltd
  *
 """
-from pytmpdir.Directory import DirSettings
-
+from peek_platform.util.LogUtil import setupPeekLogger, updatePeekLoggerHandlers, \
+    setupLoggingToSysloyServer
 from peek_plugin_base.PeekVortexUtil import peekClientName, peekServerName
+from pytmpdir.Directory import DirSettings
 from txhttputil.site.FileUploadRequest import FileUploadRequest
 from txhttputil.site.SiteUtil import setupSite
-from peek_platform.util.LogUtil import setupPeekLogger
 from vortex.DeferUtil import vortexLogFailure
 from vortex.VortexFactory import VortexFactory
 
@@ -35,6 +35,7 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+
 def setupPlatform():
     from peek_platform import PeekPlatformConfig
     PeekPlatformConfig.componentName = peekClientName
@@ -61,15 +62,25 @@ def setupPlatform():
 
     # Set default logging level
     logging.root.setLevel(PeekPlatformConfig.config.loggingLevel)
+    updatePeekLoggerHandlers(PeekPlatformConfig.componentName,
+                             PeekPlatformConfig.config.loggingRotateSizeMb,
+                             PeekPlatformConfig.config.loggingRotationsToKeep,
+                             PeekPlatformConfig.config.logToStdout)
+
+    if PeekPlatformConfig.config.loggingLogToSyslogHost:
+        setupLoggingToSysloyServer(PeekPlatformConfig.config.loggingLogToSyslogHost,
+                                   PeekPlatformConfig.config.loggingLogToSyslogPort,
+                                   PeekPlatformConfig.config.loggingLogToSyslogFacility)
 
     # Enable deferred debugging if DEBUG is on.
     if logging.root.level == logging.DEBUG:
         defer.setDebugging(True)
 
     # If we need to enable memory debugging, turn that on.
-    if PeekPlatformConfig.config.loggingDumpMemory:
+    if PeekPlatformConfig.config.loggingDebugMemoryMask:
         from peek_platform.util.MemUtil import setupMemoryDebugging
-        setupMemoryDebugging(peekServerName)
+        setupMemoryDebugging(PeekPlatformConfig.componentName,
+                             PeekPlatformConfig.config.loggingDebugMemoryMask)
 
     # Set the reactor thread count
     reactor.suggestThreadPoolSize(PeekPlatformConfig.config.twistedThreadPoolSize)
@@ -141,23 +152,22 @@ def main():
         # Create the mobile vortex server
         fieldHttpServer = PeekPlatformConfig.config.fieldHttpServer
         setupSite("Peek Field Site",
-              mobileRoot,
-              portNum=fieldHttpServer.sitePort,
-              enableLogin=False,
-              redirectFromHttpPort=fieldHttpServer.redirectFromHttpPort,
-              sslCertFilePath=fieldHttpServer.sslCertFilePath,
-              sslKeyFilePath=fieldHttpServer.sslKeyFilePath)
+                  mobileRoot,
+                  portNum=fieldHttpServer.sitePort,
+                  enableLogin=False,
+                  redirectFromHttpPort=fieldHttpServer.redirectFromHttpPort,
+                  sslCertFilePath=fieldHttpServer.sslCertFilePath,
+                  sslKeyFilePath=fieldHttpServer.sslKeyFilePath)
 
         # Create the desktop vortex server
         officeHttpServer = PeekPlatformConfig.config.officeHttpServer
         setupSite("Peek Office Site",
-              desktopRoot,
-              portNum=officeHttpServer.sitePort,
-              enableLogin=False,
-              redirectFromHttpPort=officeHttpServer.redirectFromHttpPort,
-              sslCertFilePath=officeHttpServer.sslCertFilePath,
-              sslKeyFilePath=officeHttpServer.sslKeyFilePath)
-
+                  desktopRoot,
+                  portNum=officeHttpServer.sitePort,
+                  enableLogin=False,
+                  redirectFromHttpPort=officeHttpServer.redirectFromHttpPort,
+                  sslCertFilePath=officeHttpServer.sslCertFilePath,
+                  sslKeyFilePath=officeHttpServer.sslKeyFilePath)
 
     d.addCallback(startSite)
 
